@@ -86,7 +86,7 @@
 #define KCONFIGCORE_BUILD_DEPRECATED_SINCE(major, minor) 1
 
 #ifdef KCONFIGCORE_NO_DEPRECATED
-#  define KCONFIGCORE_DISABLE_DEPRECATED_BEFORE_AND_AT 0x55b00
+#  define KCONFIGCORE_DISABLE_DEPRECATED_BEFORE_AND_AT 0x56200
 #endif
 #ifdef KCONFIGCORE_NO_DEPRECATED_WARNINGS
 #  define KCONFIGCORE_DEPRECATED_WARNINGS_SINCE 0
@@ -96,7 +96,7 @@
 #  ifdef KCONFIGCORE_DISABLE_DEPRECATED_BEFORE_AND_AT
 #    define KCONFIGCORE_DEPRECATED_WARNINGS_SINCE KCONFIGCORE_DISABLE_DEPRECATED_BEFORE_AND_AT
 #  else
-#    define KCONFIGCORE_DEPRECATED_WARNINGS_SINCE 0x55b00
+#    define KCONFIGCORE_DEPRECATED_WARNINGS_SINCE 0x56200
 #  endif
 #endif
 
@@ -211,7 +211,7 @@
 #define KCONFIGCORE_BUILD_DEPRECATED_SINCE(major, minor) 1
 
 #ifdef KCONFIGCORE_NO_DEPRECATED
-#  define KCONFIGCORE_DISABLE_DEPRECATED_BEFORE_AND_AT 0x55b00
+#  define KCONFIGCORE_DISABLE_DEPRECATED_BEFORE_AND_AT 0x56200
 #endif
 #ifdef KCONFIGCORE_NO_DEPRECATED_WARNINGS
 #  define KCONFIGCORE_DEPRECATED_WARNINGS_SINCE 0
@@ -221,7 +221,7 @@
 #  ifdef KCONFIGCORE_DISABLE_DEPRECATED_BEFORE_AND_AT
 #    define KCONFIGCORE_DEPRECATED_WARNINGS_SINCE KCONFIGCORE_DISABLE_DEPRECATED_BEFORE_AND_AT
 #  else
-#    define KCONFIGCORE_DEPRECATED_WARNINGS_SINCE 0x55b00
+#    define KCONFIGCORE_DEPRECATED_WARNINGS_SINCE 0x56200
 #  endif
 #endif
 
